<?php
# Author: Gerardo Fisanotti - AFIP/SDGSIT/DiITEC/DeARIN - 26-oct-10
# Function: Show a basic functionality trabajo_f931 SOAP client
#
# This program is supposed to be executed from the CLI, not under Apache control
# it should be invoked from the command line, like this:
#
#       $ php trabajo_f931-client.php
#
# Depending of the methods invoked (see main program at the end of this file), 
# this program will generate varios files in your default directory with the
# results obtained.
# If LOG_XMLS is TRUE, then, this program will log various files in the default
# directory, containing the request/response SOAP XML of each method invoked.
# In order to use this program you need a Ticket de Acceso (TA.xml) as provided
# by WSAA.
# The main program is at the end of this source, check it an uncomment/comment
# the lines that invoke the web methods.
#==============================================================================
# You may need to modify the following definitions to adjust to your local
# requirements.
define ("WSDL", "trabajo_f931.wsdl");   # The WSDL corresponding to WSFEX
define ("URL", "https://testdia.afip.gov.ar/diirss/trabajoF931/F931.asmx");
define ("TA", "TA.xml");                # Ticket de Acceso, from WSAA
define ("CUIT", 20131507969);           # CUIT del emisor de las FC/NC/ND
define ("PROXY_HOST", "10.20.152.112"); # Proxy IP, to reach the Internet
define ("PROXY_PORT", "80");            # Proxy TCP port
define ("LOG_XMLS", TRUE);              # For debugging purposes
#==============================================================================
function CheckErrors($results, $method, $client)
{
  if (LOG_XMLS)
  {
    file_put_contents("request-".$method.".xml",$client->__getLastRequest());
    file_put_contents("response-".$method.".xml",$client->__getLastResponse());
  }
  if (is_soap_fault($results)) 
  { printf("Fault: %s\nFaultString: %s\n",
            $results->faultcode, $results->faultstring); 
    exit (1);
  }
  $Y=$method.'Result';
  $X=$results->$Y;
  if (isset($X->CodigoRespuesta))
    {
      if ($X->CodigoRespuesta!=0)
        {
          printf("Metodo=%s Error=%s\nDescr=%s\n",$method, 
                  $X->CodigoRespuesta, $X->DescripcionRespuesta);
          exit (1);
        }
    }
}
#==============================================================================
function Dummy($client)
{
  $results=$client->Dummy();
  CheckErrors($results, 'dummy', $client);
  printf("Appserver: %s\nDbserver: %s\nAuthserver: %s\n\n",
    $results->dummyResult->appserver,
    $results->dummyResult->dbserver,
    $results->dummyResult->authserver);
}
#==============================================================================
function getRemEmpleado ($client, $token, $sign, $CUIT, $EMPLEADOR, $EMPLEADO, 
                         $PERIODO)
{
  $params->credencial->Token = $token;
  $params->credencial->Sign = $sign;
  $params->credencial->CUITDelegado = $CUIT;
  $params->cuitEmpleador = $EMPLEADOR;
  $params->cuilEmpleado = $EMPLEADO;
  $params->periodo = $PERIODO;
  $results=$client->getRemEmpleado($params);
  CheckErrors($results, 'getRemEmpleado', $client);
  $X=$results->getRemEmpleadoResult;
  printf("Periodo=%s\nTotal=%15.2f\nAPSS=%15.2f\nCOSS=%15.2f\n\n",
         $X->PeriodoFiscal, $X->RemuneracionTotal, 
         $X->RemuneracionImponibleAPSS,
         $X->RemuneracionImponibleCOSS);
}
#==============================================================================
function getDeterminativa ($client, $token, $sign, $CUIT, $EMPLEADOR, $PERIODO)
{
  $params->credencial->Token = $token;
  $params->credencial->Sign = $sign;
  $params->credencial->CUITDelegado = $CUIT;
  $params->cuitEmpleador = $EMPLEADOR;
  $params->periodo = $PERIODO;
  $results=$client->getDeterminativa($params);
  CheckErrors($results, 'getDeterminativa', $client);
  $X=$results->getDeterminativaResult;
  printf("Periodo=%s\nTotal=%15.2f\nAPSS=%15.2f\nCant.Empleados=%d\n\n",
         $X->PeriodoFiscal, $X->RemuneracionTotal, 
         $X->RemuneracionImponibleAPSS,
         $X->CantidadEmpleados);
}
#==============================================================================
ini_set("soap.wsdl_cache_enabled", "0");
if (!file_exists(WSDL)) {exit("Failed to open ".WSDL."\n");}
if (!file_exists(TA)) {exit("Failed to open ".TA."\n");}
$client=new soapClient(WSDL,
  array('soap_version' => SOAP_1_2,
        'location'     => URL,
#        'proxy_host'   => PROXY_HOST,
#        'proxy_port'   => PROXY_PORT,
        'exceptions'   => 0,
        'encoding'     => 'ISO-8859-1',
        'features'     => SOAP_USE_XSI_ARRAY_TYPE + SOAP_SINGLE_ELEMENT_ARRAYS,
        'trace'        => 1)); # needed by getLastRequestHeaders and others
$TA=simplexml_load_file(TA);
$token=$TA->credentials->token;
$sign=$TA->credentials->sign;
#file_put_contents("functions.txt",print_r($client->__getFunctions(),TRUE));
#file_put_contents("types.txt",print_r($client->__getTypes(),TRUE));
#
# Uncomment any of the following lines to invoke the corresponding web method.
#
Dummy($client);
getRemEmpleado($client, $token, $sign, CUIT, 20000000931, 20005746451, 201005);
getDeterminativa($client, $token, $sign, CUIT, 20000000931, 201005);
?>
